/* This file is part of pr-downloader (GPL v2 or later), see the LICENSE file */

#include "IDownloadsObserver.h"
#include "Download.h"

void IDownloadsObserver::Add(IDownload* /*dl*/)
{

}

void IDownloadsObserver::Remove(IDownload* /*dl*/)
{

}
